==> root-system_5.34.00.orig.tar.gz: root-system-5.34.00.orig/roofit/roofitcore/inc/LinkDef3.h <==
#ifdef __CINT__ 
#pragma link off all globals;
#pragma link off all classes;
#pragma link off all functions;
#pragma link C++ class RooCacheManager<vector<double> >+ ;
#pragma link C++ class list<RooAbsData*>+ ;
#pragma link C++ class map<string,RooAbsData*>+ ;
#pragma link C++ class RooCacheManager<RooAbsCacheElement>+ ;
#pragma link C++ class RooRandomizeParamMCSModule+ ;
#pragma link C++ class RooRangeBinning+ ;
#pragma link C++ class RooRealAnalytic+ ;
#pragma link C++ class RooRealBinding+ ;
#pragma link C++ class RooRealConstant+ ;
#pragma link C++ class RooRealIntegral+ ;
#pragma link C++ class RooRealMPFE+ ;
#pragma link C++ class RooRealProxy+ ;
#pragma link C++ class RooRealVar- ;
#pragma link C++ class RooRealVarSharedProperties+ ;
#pragma link C++ class RooRefCountList+ ;
#pragma link C++ class RooScaledFunc+ ;
#pragma link C++ class RooSegmentedIntegrator1D+ ;
#pragma link C++ class RooSegmentedIntegrator2D+ ;
#pragma link C++ class RooSetPair+ ;
#pragma link C++ class RooSetProxy+ ;
#pragma link C++ class RooSharedProperties+ ;
#pragma link C++ class RooSharedPropertiesList+ ;
#pragma link C++ class RooSimGenContext+ ;
#pragma link C++ class RooSimSplitGenContext+ ;
#pragma link C++ class RooStreamParser+ ;
#pragma link C++ class RooStringVar+ ;
#pragma link C++ class RooSuperCategory+ ;
#pragma link C++ class RooTable+ ;
#pragma link C++ class RooThreshEntry+ ;
#pragma link C++ class RooThresholdCategory+ ;
#pragma link C++ class RooTObjWrap+ ;
#pragma link C++ class RooTrace+ ;
#pragma link C++ class RooUniformBinning+ ;
#pragma link C++ class RooSimultaneous+ ;
#pragma link C++ class RooRealSumPdf+ ;
#pragma link C++ class RooResolutionModel+ ;
#pragma link C++ class RooTruthModel+ ;
#pragma link C++ class RooProdPdf+ ;
#pragma link C++ class RooSimPdfBuilder+ ;
#pragma link C++ class RooMCStudy+ ;
#pragma link C++ class RooMsgService+ ;
#pragma link C++ class RooMsgService::StreamConfig+ ;
#pragma link C++ class RooProjectedPdf+ ;
#pragma link C++ class RooWorkspace- ;
#pragma link C++ class RooWorkspace::CodeRepo- ;
#pragma link C++ class RooWorkspace::WSDir+ ;
#pragma link C++ class list<TObject*>+ ;
#pragma link C++ class list<RooAbsData*>+ ;
#pragma link C++ class RooProfileLL+ ;
#pragma link C++ class RooAbsCachedPdf+ ;
#pragma link C++ class RooAbsSelfCachedPdf+ ;
#pragma link C++ class RooHistPdf- ;
#pragma link C++ class RooCachedPdf+ ;
#pragma link C++ class RooFFTConvPdf+ ;
#pragma link C++ class RooDataHistSliceIter+ ;
#pragma link C++ class RooObjCacheManager+ ;
#pragma link C++ class RooAbsCache+ ;
#pragma link C++ class RooAbsCacheElement+ ;
#pragma link C++ class RooExtendedTerm+ ;
#pragma link C++ class RooSentinel+ ;
#pragma link C++ class RooParamBinning+ ;
#pragma link C++ class RooConstraintSum+ ;
#pragma link C++ class RooRecursiveFraction+ ;
#pragma link C++ class RooDataWeightedAverage+ ;
#pragma link C++ class RooSimWSTool+ ;
#pragma link C++ class RooSimWSTool::SplitRule+ ;
#pragma link C++ class RooSimWSTool::BuildConfig+ ;
#pragma link C++ class RooSimWSTool::MultiBuildConfig+ ;
#pragma link C++ class RooSimWSTool::ObjSplitRule+ ;
#pragma link C++ class RooSimWSTool::ObjBuildConfig+ ;
#pragma link C++ class RooFracRemainder+ ;
#pragma link C++ class RooAbsCachedReal+ ;
#pragma link C++ class RooAbsSelfCachedReal+ ;
#pragma link C++ class RooCachedReal+ ;
#pragma link C++ class RooNumCdf+ ;
#pragma link C++ class RooChangeTracker+ ;
#pragma link C++ class RooNumRunningInt+ ;
#pragma link C++ class RooHistFunc- ;
#pragma link C++ class RooExpensiveObjectCache+ ;
#pragma link C++ class RooExpensiveObjectCache::ExpensiveObject+ ;
#pragma link C++ class std::map<std::string,RooAbsPdf*>+ ;
// The nomap options excludes the class from the roomap file
#pragma link C++ options=nomap class std::map<std::string,TH1*>+ ;
#pragma link C++ class std::map<std::string,RooAbsDataStore*>+ ;
#pragma link C++ class std::list<RooAbsData*>+ ;
#pragma link C++ class std::list<TObject*>+ ;
#pragma link C++ class RooFactoryWSTool+ ;
#pragma link C++ class RooBinningCategory+ ;
#pragma link C++ class RooDerivative+ ;
#pragma link C++ class RooFunctor+ ;
#pragma link C++ class RooGenFunction+ ;
#pragma link C++ class RooMultiGenFunction+ ;
#pragma link C++ class RooTFoamBinding+ ;
#pragma link C++ class RooAdaptiveIntegratorND+ ;
#pragma link C++ class RooAbsNumGenerator+ ;
#pragma link C++ class RooFoamGenerator+ ;
#pragma link C++ class RooNumGenConfig+ ;
#pragma link C++ class RooNumGenFactory+ ;
#pragma link C++ class RooMultiVarGaussian+ ;
#pragma link C++ class RooMultiVarGaussian::AnaIntData+ ;
#pragma link C++ class RooMultiVarGaussian::GenData+ ;
#pragma link C++ class RooXYChi2Var+ ;
#pragma link C++ class RooAbsDataStore+ ;
#pragma link C++ class RooTreeDataStore- ;
#pragma link C++ class RooCompositeDataStore+ ;
#pragma link C++ class RooTreeData+ ;
#pragma link C++ class RooRangeBoolean+ ;
#pragma link C++ class RooVectorDataStore- ;
#pragma link C++ class RooVectorDataStore::RealVector- ;
#pragma link C++ class RooVectorDataStore::RealFullVector- ;
#pragma link C++ class RooVectorDataStore::CatVector- ;
#pragma link C++ class std::pair<std::string,RooAbsData*>+ ;
#pragma link C++ class pair<int,RooLinkedListElem*>+ ;
#pragma link C++ class RooUnitTest+ ;
#ifndef __ROOFIT_NOROOMINIMIZER
#pragma link C++ class RooMinimizer+ ;
#pragma link C++ class RooMinimizerFcn+ ;
#endif
#pragma link C++ class RooMoment+ ;
#pragma link C++ class RooStudyManager+ ;
#pragma link C++ class RooStudyPackage+ ;
#pragma link C++ class RooAbsStudy+ ;
#pragma link C++ class RooGenFitStudy+ ;
#pragma link C++ class RooProofDriverSelector+ ;
#pragma link C++ class list<RooAbsStudy*>+ ;
#pragma link C++ class map<string,RooDataSet*>+ ;
#pragma link C++ class map<string,RooDataHist*>+ ;
// The nomap options excludes the class from the roomap file
#pragma link C++ options=nomap class map<string,TH1*>+ ;
#pragma link C++ namespace RooCintUtils+ ;
#pragma link off class RooErrorHandler+ ;
#pragma link off class RooNag+ ;
#endif

==> root-system_5.34.06.orig.tar.gz: root-system-5.34.06.orig/roofit/roofitcore/inc/LinkDef3.h <==
#ifdef __CINT__ 
#pragma link off all globals;
#pragma link off all classes;
#pragma link off all functions;
#pragma link C++ class RooCacheManager<std::vector<double> >+ ;
#pragma link C++ class std::list<RooAbsData*>+ ;
#pragma link C++ class std::map<string,RooAbsData*>+ ;
#pragma link C++ class RooCacheManager<RooAbsCacheElement>+ ;
#pragma link C++ class RooRandomizeParamMCSModule+ ;
#pragma link C++ class RooRangeBinning+ ;
#pragma link C++ class RooRealAnalytic+ ;
#pragma link C++ class RooRealBinding+ ;
#pragma link C++ class RooRealConstant+ ;
#pragma link C++ class RooRealIntegral+ ;
#pragma link C++ class RooRealMPFE+ ;
#pragma link C++ class RooRealProxy+ ;
#pragma link C++ class RooRealVar- ;
#pragma link C++ class RooRealVarSharedProperties+ ;
#pragma link C++ class RooRefCountList+ ;
#pragma link C++ class RooScaledFunc+ ;
#pragma link C++ class RooSegmentedIntegrator1D+ ;
#pragma link C++ class RooSegmentedIntegrator2D+ ;
#pragma link C++ class RooSetPair+ ;
#pragma link C++ class RooSetProxy+ ;
#pragma link C++ class RooSharedProperties+ ;
#pragma link C++ class RooSharedPropertiesList+ ;
#pragma link C++ class RooSimGenContext+ ;
#pragma link C++ class RooSimSplitGenContext+ ;
#pragma link C++ class RooStreamParser+ ;
#pragma link C++ class RooStringVar+ ;
#pragma link C++ class RooSuperCategory+ ;
#pragma link C++ class RooTable+ ;
#pragma link C++ class RooThreshEntry+ ;
#pragma link C++ class RooThresholdCategory+ ;
#pragma link C++ class RooTObjWrap+ ;
#pragma link C++ class RooTrace+ ;
#pragma link C++ class RooUniformBinning+ ;
#pragma link C++ class RooSimultaneous+ ;
#pragma link C++ class RooRealSumPdf+ ;
#pragma link C++ class RooResolutionModel+ ;
#pragma link C++ class RooTruthModel+ ;
#pragma link C++ class RooProdPdf+ ;
#pragma link C++ class RooSimPdfBuilder+ ;
#pragma link C++ class RooMCStudy+ ;
#pragma link C++ class RooMsgService+ ;
#pragma link C++ class RooMsgService::StreamConfig+ ;
#pragma link C++ class RooProjectedPdf+ ;
#pragma link C++ class RooWorkspace- ;
#pragma link C++ class RooWorkspace::CodeRepo- ;
#pragma link C++ class RooWorkspace::WSDir+ ;
#pragma link C++ class std::list<TObject*>+ ;
#pragma link C++ class std::list<RooAbsData*>+ ;
#pragma link C++ class RooProfileLL+ ;
#pragma link C++ class RooAbsCachedPdf+ ;
#pragma link C++ class RooAbsSelfCachedPdf+ ;
#pragma link C++ class RooHistPdf- ;
#pragma link C++ class RooCachedPdf+ ;
#pragma link C++ class RooFFTConvPdf+ ;
#pragma link C++ class RooDataHistSliceIter+ ;
#pragma link C++ class RooObjCacheManager+ ;
#pragma link C++ class RooAbsCache+ ;
#pragma link C++ class RooAbsCacheElement+ ;
#pragma link C++ class RooExtendedTerm+ ;
#pragma link C++ class RooSentinel+ ;
#pragma link C++ class RooParamBinning+ ;
#pragma link C++ class RooConstraintSum+ ;
#pragma link C++ class RooRecursiveFraction+ ;
#pragma link C++ class RooDataWeightedAverage+ ;
#pragma link C++ class RooSimWSTool+ ;
#pragma link C++ class RooSimWSTool::SplitRule+ ;
#pragma link C++ class RooSimWSTool::BuildConfig+ ;
#pragma link C++ class RooSimWSTool::MultiBuildConfig+ ;
#pragma link C++ class RooSimWSTool::ObjSplitRule+ ;
#pragma link C++ class RooSimWSTool::ObjBuildConfig+ ;
#pragma link C++ class RooFracRemainder+ ;
#pragma link C++ class RooAbsCachedReal+ ;
#pragma link C++ class RooAbsSelfCachedReal+ ;
#pragma link C++ class RooCachedReal+ ;
#pragma link C++ class RooNumCdf+ ;
#pragma link C++ class RooChangeTracker+ ;
#pragma link C++ class RooNumRunningInt+ ;
#pragma link C++ class RooHistFunc- ;
#pragma link C++ class RooExpensiveObjectCache+ ;
#pragma link C++ class RooExpensiveObjectCache::ExpensiveObject+ ;
#pragma link C++ class std::map<std::string,RooAbsPdf*>+ ;
// The nomap options excludes the class from the roomap file
#pragma link C++ options=nomap class std::map<std::string,TH1*>+ ;
#pragma link C++ class std::map<std::string,RooAbsDataStore*>+ ;
#pragma link C++ class std::list<RooAbsData*>+ ;
#pragma link C++ class std::list<TObject*>+ ;
#pragma link C++ class RooFactoryWSTool+ ;
#pragma link C++ class RooBinningCategory+ ;
#pragma link C++ class RooDerivative+ ;
#pragma link C++ class RooFunctor+ ;
#pragma link C++ class RooGenFunction+ ;
#pragma link C++ class RooMultiGenFunction+ ;
#pragma link C++ class RooTFoamBinding+ ;
#pragma link C++ class RooAdaptiveIntegratorND+ ;
#pragma link C++ class RooAbsNumGenerator+ ;
#pragma link C++ class RooFoamGenerator+ ;
#pragma link C++ class RooNumGenConfig+ ;
#pragma link C++ class RooNumGenFactory+ ;
#pragma link C++ class RooMultiVarGaussian+ ;
#pragma link C++ class RooMultiVarGaussian::AnaIntData+ ;
#pragma link C++ class RooMultiVarGaussian::GenData+ ;
#pragma link C++ class RooXYChi2Var+ ;
#pragma link C++ class RooAbsDataStore+ ;
#pragma link C++ class RooTreeDataStore- ;
#pragma link C++ class RooCompositeDataStore+ ;
#pragma link C++ class RooTreeData+ ;
#pragma link C++ class RooRangeBoolean+ ;
#pragma link C++ class RooVectorDataStore- ;
#pragma link C++ class RooVectorDataStore::RealVector- ;
#pragma link C++ class RooVectorDataStore::RealFullVector- ;
#pragma link C++ class RooVectorDataStore::CatVector- ;
#pragma link C++ class std::pair<std::string,RooAbsData*>+ ;
#pragma link C++ class std::pair<int,RooLinkedListElem*>+ ;
#pragma link C++ class RooUnitTest+ ;
#ifndef __ROOFIT_NOROOMINIMIZER
#pragma link C++ class RooMinimizer+ ;
#pragma link C++ class RooMinimizerFcn+ ;
#endif
#pragma link C++ class RooMoment+ ;
#pragma link C++ class RooStudyManager+ ;
#pragma link C++ class RooStudyPackage+ ;
#pragma link C++ class RooAbsStudy+ ;
#pragma link C++ class RooGenFitStudy+ ;
#pragma link C++ class RooProofDriverSelector+ ;
#pragma link C++ class std::list<RooAbsStudy*>+ ;
#pragma link C++ class std::map<string,RooDataSet*>+ ;
#pragma link C++ class std::map<string,RooDataHist*>+ ;
// The nomap options excludes the class from the roomap file
#pragma link C++ options=nomap class std::map<string,TH1*>+ ;
#pragma link C++ namespace RooCintUtils+ ;
#pragma link off class RooErrorHandler+ ;
#endif
